==> ocre_v0_031.tgz: ocre-0.031/ocre/src/parcela.c <==

#include <stdio.h>

#include "aplica.h"
#include "grises.h"
#include "histos.h"
#include "imag.h"
#include "imagx.h"
#include "inclina.h"
#include "line.h"
#include "lista.h"
#include "lvent.h"
// #include "opcionesp.h"
#include "opcns.h"
#include "pinta.h"
#include "segmenta0.h"

void separaCabecera (tvent vent)
{
  tline linea;
  tvent vent1, vent2;
  lista lv;
  posicionLineaCabecera (&linea, vent);
  lv = listaNueva ();
  ventanaEnVentanaLargHor (&vent1, vent, 0, linea->v0 - 2);
  ventanaEnVentanaLargHor (&vent2, vent, linea->v1 + 2, vent->ty - linea->v1 - 2);
  anyadeVentana (lv, vent1);
  anyadeVentana (lv, vent2);
  vent->lvint = lv;
}

void separaColumnaspBoe (tvent vent)
{
  int centroLineaBl;
  tline linea;
  tvent vent1, vent2;
  lista lv;
  posicionMargenColumnas (&linea, vent);
  lv = listaNueva ();
  centroLineaBl = (linea->v1 + linea->v0) / 2;
  ventanaEnVentanaLargVer (&vent1, vent, 0, centroLineaBl - 2);
  ventanaEnVentanaLargVer (&vent2, vent, centroLineaBl + 3, vent->tx - centroLineaBl - 3);
  anyadeVentana (lv, vent1);
  anyadeVentana (lv, vent2);
  vent->lvint = lv;
}

void separaColumnasp (tvent vent)
{
  int centroLineaBl;
  tline linea;
  tvent vent1, vent2;
  lista lv;
  posicionMargenColumnas (&linea, vent);
  lv = listaNueva ();
  centroLineaBl = (linea->v1 + linea->v0) / 2;
  ventanaEnVentanaLargVer (&vent1, vent, 0, centroLineaBl - 2);
  ventanaEnVentanaLargVer (&vent2, vent, centroLineaBl + 3, vent->tx - centroLineaBl - 3);
  anyadeVentana (lv, vent1);
  anyadeVentana (lv, vent2);
  vent->lvint = lv;
}

void partesVColumna (tvent vent)
{
  int centroLineaBl, yant;
  lista lineas;
  tvent vent1;
  lista lv;
  tnodol nodol;
  posicionesMargenesSeccion (&lineas, vent);
  if (longLista(lineas) > 0) {
    lv = listaNueva ();
    yant = -1;
    for (nodol = lineas->primero; nodol != 0L; nodol = nodol->siguiente) {
      tline linea;
      linea = (tline) nodol->aitem;
      centroLineaBl = (linea->v1 + linea->v0) / 2;
      ventanaEnVentanaLargHor (&vent1, vent, yant + 1, centroLineaBl - 2 - yant - 1);
      anyadeVentana (lv, vent1);
      yant = centroLineaBl + 2;
      }
    ventanaEnVentanaLargHor (&vent1, vent, yant + 1, vent->ty-1 - yant - 1);
    anyadeVentana (lv, vent1);
    vent->lvint = lv;
    }
}

void partesVColumnas (tvent vent)
{
  aplicaLvents (vent->lvint, partesVColumna);
}

void partesHColumna (tvent vent)
{
  int centroLineaBl, xcant, v1ant;
  lista lineas;
  tvent ventl;
  int inclv;
  lista lv;
  tnodol nodol;
  inclv = calculaInclinacionV (vent);
  posicionesMargenesMinipage (&lineas, vent);
  if (longLista(lineas) > 0) {
    lv = listaNueva ();
    xcant = -1;
    v1ant = -100 ;  /*  cualquier valor mayor que el 7 usado mas abajo (if) */
    for (nodol = lineas->primero; nodol != 0L; nodol = nodol->siguiente) {
      tline linea;
      linea = (tline) nodol->aitem;
      centroLineaBl = (linea->v1 + linea->v0) / 2;
      if ((linea->v0 - v1ant) >= 7) {
	printf ("%6d, %6d\n",
			xcant +1, centroLineaBl - 2 - xcant - 1);
        ventanaEnVentanaLargVerInclLimpConMargen (&ventl, vent, xcant +1,
			                          centroLineaBl - 2 - xcant - 1, inclv);
        anyadeVentana (lv, ventl);
        }
      xcant = centroLineaBl + 2;
      v1ant = linea->v1;
      }
    if ((vent->tx-1 - v1ant) >= 7) {
      printf ("%6d, %6d %6d %6d %6d\n", xcant +1, vent->tx - 1 - xcant - 1, inclv, vent->tx-1, v1ant);
      ventanaEnVentanaLargVerInclLimpConMargen (&ventl, vent, xcant +1,
		                              vent->tx - 1 - xcant - 1, inclv);
      anyadeVentana (lv, ventl);
      }
    vent->lvint = lv;
    }
}

void partesHColumnaDrae (tvent vent)
{
  /*
  int centroLineaBl, xcant, v1ant;
  lista lineas;
  tvent ventl;
  int inclv;
  lista lv;
  tnodol nodol;
  */
  printf ("parcela.partesHColumnaDrae\n");
  prepara0 (vent);
  sigueRayas (vent);
  /*
  inclv = calculaInclinacionV (vent);
  posicionesMargenesMinipage (&lineas, vent);
  if (longLista(lineas) > 0) {
    lv = listaNueva ();
    xcant = -1;
    v1ant = -100 ;  / *  cualquier valor mayor que el 7 usado mas abajo (if) * /
    for (nodol = lineas->primero; nodol != 0L; nodol = nodol->siguiente) {
      tline linea;
      linea = (tline) nodol->aitem;
      centroLineaBl = (linea->v1 + linea->v0) / 2;
      if ((linea->v0 - v1ant) >= 7) {
	printf ("%6d, %6d\n",
			xcant +1, centroLineaBl - 2 - xcant - 1);
        ventanaEnVentanaLargVerInclLimpConMargen (&ventl, vent, xcant +1,
			                          centroLineaBl - 2 - xcant - 1, inclv);
        anyadeVentana (lv, ventl);
        }
      xcant = centroLineaBl + 2;
      v1ant = linea->v1;
      }
    if ((vent->tx-1 - v1ant) >= 7) {
      printf ("%6d, %6d %6d %6d %6d\n", xcant +1, vent->tx - 1 - xcant - 1, inclv, vent->tx-1, v1ant);
      ventanaEnVentanaLargVerInclLimpConMargen (&ventl, vent, xcant +1,
		                              vent->tx - 1 - xcant - 1, inclv);
      anyadeVentana (lv, ventl);
      }
    vent->lvint = lv;
    }
    */
}

void partesHColumnas0 (tvent vent)
{
  aplicaLvents (vent->lvint, partesHColumna);
}

void partesHColumnas (tvent vent)
{
  aplicaLvents (vent->lvint, partesHColumnas0);
}

void pintayPresenta (tvent vent)
{
  int nh1;
  /*
  pintaRectIntVentanasHojRecur (vent, 4);
  */
  pintaRectIntVentanasRecur (vent, 4);
  presentaVentana (& nh1, vent, "sal26i.pgm", 1);
}

void parcela2 (tvent vent)
{
  tvent vprin;
  separaCabecera  (vent);
  vprin = seleccionaSubventana (vent, "cadr");
  separaColumnaspBoe (vprin);
  partesVColumnas (vprin);
  partesHColumnas (vprin);
}
/* */
void parcela3 (tvent vent)
{
  partesHColumna (vent);
}
/* */
void parcela (tvent vent)
{
  if (A_opcion){
    partesHColumnaDrae (vent);
    } 
  else
    parcela3 (vent);
  /*
  pintayPresenta (vent);
  exit (0);
  */
}

/* ---------- ---------- */

==> ocre_v0_033.tgz: ocre-0.033/ocre/src/parcela.c <==

#include <stdio.h>

#include "aplica.h"
#include "grises.h"
#include "histos.h"
#include "imag.h"
#include "imagx.h"
#include "inclina.h"
#include "line.h"
#include "lista.h"
#include "lvent.h"
// #include "opcionesp.h"
#include "opcns.h"
#include "pinta.h"
#include "segmenta0.h"

void partesHColumna (tvent vent)
{
  int centroLineaBl, xcant, v1ant;
  lista lineas;
  tvent ventl;
  int inclv;
  lista lv;
  tnodol nodol;
  inclv = calculaInclinacionV (vent);
  posicionesMargenesMinipage (&lineas, vent);
  if (longLista(lineas) > 0) {
    lv = listaNueva ();
    xcant = -1;
    v1ant = -100 ;  /*  cualquier valor mayor que el 7 usado mas abajo (if) */
    for (nodol = lineas->primero; nodol != 0L; nodol = nodol->siguiente) {
      tline linea;
      linea = (tline) nodol->aitem;
      centroLineaBl = (linea->v1 + linea->v0) / 2;
      if ((linea->v0 - v1ant) >= 7) {
	printf ("%6d, %6d\n",
			xcant +1, centroLineaBl - 2 - xcant - 1);
        ventanaEnVentanaLargVerInclLimpConMargen (&ventl, vent, xcant +1,
			                          centroLineaBl - 2 - xcant - 1, inclv);
        anyadeVentana (lv, ventl);
        }
      xcant = centroLineaBl + 2;
      v1ant = linea->v1;
      }
    if ((vent->tx-1 - v1ant) >= 7) {
      printf ("%6d, %6d %6d %6d %6d\n",
               xcant +1, vent->tx - 1 - xcant - 1,
               inclv, vent->tx-1, v1ant);
      ventanaEnVentanaLargVerInclLimpConMargen (&ventl, vent, xcant +1,
		                              vent->tx - 1 - xcant - 1, inclv);
      anyadeVentana (lv, ventl);
      }
    vent->lvint = lv;
    }
}

void partesVColumna (tvent vent)
{
  int centroLineaBl, yant;
  lista lineas;
  tvent vent1;
  lista lv;
  tnodol nodol;
  posicionesMargenesSeccion (&lineas, vent);
  if (longLista(lineas) > 0) {
    lv = listaNueva ();
    yant = -1;
    for (nodol = lineas->primero; nodol != 0L; nodol = nodol->siguiente) {
      tline linea;
      linea = (tline) nodol->aitem;
      centroLineaBl = (linea->v1 + linea->v0) / 2;
      ventanaEnVentanaLargHor (&vent1, vent, yant + 1, centroLineaBl - 2 - yant - 1);
      anyadeVentana (lv, vent1);
      yant = centroLineaBl + 2;
      }
    ventanaEnVentanaLargHor (&vent1, vent, yant + 1, vent->ty-1 - yant - 1);
    anyadeVentana (lv, vent1);
    vent->lvint = lv;
    }
}

void partesVColumnas (tvent vent)
{
  aplicaLvents (vent->lvint, partesVColumna);
}

void partesHColumnas0 (tvent vent)
{
  aplicaLvents (vent->lvint, partesHColumna);
}

void partesHColumnas (tvent vent)
{
  aplicaLvents (vent->lvint, partesHColumnas0);
}

// -------------------- BOE --------------------

void separaCabecera (tvent vent)
{
  tline linea;
  tvent vent1, vent2;
  lista lv;
  posicionLineaCabecera (&linea, vent);
  lv = listaNueva ();
  ventanaEnVentanaLargHor (&vent1, vent, 0, linea->v0 - 2);
  ventanaEnVentanaLargHor (&vent2, vent, linea->v1 + 2, vent->ty - linea->v1 - 2);
  anyadeVentana (lv, vent1);
  anyadeVentana (lv, vent2);
  vent->lvint = lv;
}

void separaColumnaspBoe (tvent vent)
{
  int centroLineaBl;
  tline linea;
  tvent vent1, vent2;
  lista lv;
  posicionMargenColumnas (&linea, vent);
  lv = listaNueva ();
  centroLineaBl = (linea->v1 + linea->v0) / 2;
  ventanaEnVentanaLargVer (&vent1, vent, 0, centroLineaBl - 2);
  ventanaEnVentanaLargVer (&vent2, vent, centroLineaBl + 3, vent->tx - centroLineaBl - 3);
  anyadeVentana (lv, vent1);
  anyadeVentana (lv, vent2);
  vent->lvint = lv;
}

void parcela2 (tvent vent)
{
  tvent vprin;
  separaCabecera  (vent);
  vprin = seleccionaSubventana (vent, "cadr");
  separaColumnaspBoe (vprin);
  partesVColumnas (vprin);
  partesHColumnas (vprin);
}

// -------------------- DRAE --------------------

void separaColumnasp (tvent vent)
{
  int centroLineaBl;
  tline linea;
  tvent vent1, vent2;
  lista lv;
  posicionMargenColumnas (&linea, vent);
  lv = listaNueva ();
  centroLineaBl = (linea->v1 + linea->v0) / 2;
  ventanaEnVentanaLargVer (&vent1, vent, 0, centroLineaBl - 2);
  ventanaEnVentanaLargVer (&vent2, vent, centroLineaBl + 3, vent->tx - centroLineaBl - 3);
  anyadeVentana (lv, vent1);
  anyadeVentana (lv, vent2);
  vent->lvint = lv;
}

void partesHColumnaDrae (tvent vent)
{
  /*
  int centroLineaBl, xcant, v1ant;
  lista lineas;
  tvent ventl;
  int inclv;
  lista lv;
  tnodol nodol;
  */
  printf ("parcela.partesHColumnaDrae\n");
  prepara0 (vent);
  sigueRayas (vent);
  /*
  inclv = calculaInclinacionV (vent);
  posicionesMargenesMinipage (&lineas, vent);
  if (longLista(lineas) > 0) {
    lv = listaNueva ();
    xcant = -1;
    v1ant = -100 ;  / *  cualquier valor mayor que el 7 usado mas abajo (if) * /
    for (nodol = lineas->primero; nodol != 0L; nodol = nodol->siguiente) {
      tline linea;
      linea = (tline) nodol->aitem;
      centroLineaBl = (linea->v1 + linea->v0) / 2;
      if ((linea->v0 - v1ant) >= 7) {
	printf ("%6d, %6d\n",
			xcant +1, centroLineaBl - 2 - xcant - 1);
        ventanaEnVentanaLargVerInclLimpConMargen (&ventl, vent, xcant +1,
			                          centroLineaBl - 2 - xcant - 1, inclv);
        anyadeVentana (lv, ventl);
        }
      xcant = centroLineaBl + 2;
      v1ant = linea->v1;
      }
    if ((vent->tx-1 - v1ant) >= 7) {
      printf ("%6d, %6d %6d %6d %6d\n", xcant +1, vent->tx - 1 - xcant - 1, inclv, vent->tx-1, v1ant);
      ventanaEnVentanaLargVerInclLimpConMargen (&ventl, vent, xcant +1,
		                              vent->tx - 1 - xcant - 1, inclv);
      anyadeVentana (lv, ventl);
      }
    vent->lvint = lv;
    }
    */
}

// -------------------- ocre-gen --------------------

void pintayPresenta (tvent vent)
{
  int nh1;
  // pintaRectIntVentanasHojRecur (vent, 4);
  pintaRectIntVentanasRecur (vent, 4);
  presentaVentana (& nh1, vent, "sal26i.pgm", 1);
}


void parcela3 (tvent vent)
{
  partesHColumna (vent);
}

void parcela (tvent vent)
{
  if (A_opcion){
    partesHColumnaDrae (vent);
    } 
  else
    parcela3 (vent);
  // pintayPresenta (vent);
  // exit (0);
}
